==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/javascript/NpmConfig.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) File representing the local NPM config in .npmrc.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.886Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.NpmConfig")
public class NpmConfig extends io.github.cdklabs.projen.Component {

    protected NpmConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected NpmConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public NpmConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.NpmConfigOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public NpmConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) configure a generic property.
     * <p>
     * @param name the name of the property. This parameter is required.
     * @param value the value of the property. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addConfig(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.call(this, "addConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * (experimental) configure a scoped registry.
     * <p>
     * @param url the URL of the registry to use. This parameter is required.
     * @param scope the scope the registry is used for;.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addRegistry(final @org.jetbrains.annotations.NotNull java.lang.String url, final @org.jetbrains.annotations.Nullable java.lang.String scope) {
        software.amazon.jsii.Kernel.call(this, "addRegistry", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(url, "url is required"), scope });
    }

    /**
     * (experimental) configure a scoped registry.
     * <p>
     * @param url the URL of the registry to use. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addRegistry(final @org.jetbrains.annotations.NotNull java.lang.String url) {
        software.amazon.jsii.Kernel.call(this, "addRegistry", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(url, "url is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.javascript.NpmConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.javascript.NpmConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private io.github.cdklabs.projen.javascript.NpmConfigOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
        }

        /**
         * (experimental) URL of the registry mirror to use.
         * <p>
         * You can change this or add scoped registries using the addRegistry method
         * <p>
         * Default: - use npmjs default registry
         * <p>
         * @return {@code this}
         * @param registry URL of the registry mirror to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder registry(final java.lang.String registry) {
            this.options().registry(registry);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.javascript.NpmConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.javascript.NpmConfig build() {
            return new io.github.cdklabs.projen.javascript.NpmConfig(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.javascript.NpmConfigOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.javascript.NpmConfigOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/javascript/NpmConfig.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) File representing the local NPM config in .npmrc.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.542Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.NpmConfig")
public class NpmConfig extends io.github.cdklabs.projen.Component {

    protected NpmConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected NpmConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public NpmConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.NpmConfigOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public NpmConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) configure a generic property.
     * <p>
     * @param name the name of the property. This parameter is required.
     * @param value the value of the property. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addConfig(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.call(this, "addConfig", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * (experimental) configure a scoped registry.
     * <p>
     * @param url the URL of the registry to use. This parameter is required.
     * @param scope the scope the registry is used for;.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addRegistry(final @org.jetbrains.annotations.NotNull java.lang.String url, final @org.jetbrains.annotations.Nullable java.lang.String scope) {
        software.amazon.jsii.Kernel.call(this, "addRegistry", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(url, "url is required"), scope });
    }

    /**
     * (experimental) configure a scoped registry.
     * <p>
     * @param url the URL of the registry to use. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addRegistry(final @org.jetbrains.annotations.NotNull java.lang.String url) {
        software.amazon.jsii.Kernel.call(this, "addRegistry", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(url, "url is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.javascript.NpmConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.javascript.NpmConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private io.github.cdklabs.projen.javascript.NpmConfigOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
        }

        /**
         * (experimental) Omits empty objects and arrays.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param omitEmpty Omits empty objects and arrays. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder omitEmpty(final java.lang.Boolean omitEmpty) {
            this.options().omitEmpty(omitEmpty);
            return this;
        }

        /**
         * (experimental) URL of the registry mirror to use.
         * <p>
         * You can change this or add scoped registries using the addRegistry method
         * <p>
         * Default: - use npmjs default registry
         * <p>
         * @return {@code this}
         * @param registry URL of the registry mirror to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder registry(final java.lang.String registry) {
            this.options().registry(registry);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.javascript.NpmConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.javascript.NpmConfig build() {
            return new io.github.cdklabs.projen.javascript.NpmConfig(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.javascript.NpmConfigOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.javascript.NpmConfigOptions.Builder();
            }
            return this.options;
        }
    }
}
